@@ -15,7 +15,7 @@ def layer_names(state):
     names : list
         List of layer names
     """
-    return [l['name'] for l in state['layers']]
+    return [l["name"] for l in state["layers"]]
 
 
 def image_layers(state):
@@ -31,7 +31,7 @@ def image_layers(state):
     names : list
         List of layer names
     """
-    return [l['name'] for l in state['layers'] if l['type'] == 'image']
+    return [l["name"] for l in state["layers"] if l["type"] == "image"]
 
 
 def segmentation_layers(state):
@@ -47,7 +47,7 @@ def segmentation_layers(state):
     names : list
         List of layer names
     """
-    return [l['name'] for l in state['layers'] if l['type'] in SEGMENTATION_LAYER_TYPES]
+    return [l["name"] for l in state["layers"] if l["type"] in SEGMENTATION_LAYER_TYPES]
 
 
 def annotation_layers(state):
@@ -63,7 +63,7 @@ def annotation_layers(state):
     names : list
         List of layer names
     """
-    return [l['name'] for l in state['layers'] if l['type'] == 'annotation']
+    return [l["name"] for l in state["layers"] if l["type"] == "annotation"]
 
 
 def tag_dictionary(state, layer_name):
@@ -82,10 +82,10 @@ def tag_dictionary(state, layer_name):
         [description]
     """
     l = get_layer(state, layer_name)
-    taginfo = l.get('annotationTags', [])
+    taginfo = l.get("annotationTags", [])
     tags = {}
     for t in taginfo:
-        tags[int(t['id'])] = t['label']
+        tags[int(t["id"])] = t["label"]
     return tags
 
 
@@ -105,7 +105,7 @@ def get_layer(state, layer_name):
         Layer data contents
     """
     layer_ind = layer_names(state).index(layer_name)
-    return state['layers'][layer_ind]
+    return state["layers"][layer_ind]
 
 
 def view_settings(state):
@@ -124,11 +124,11 @@ def view_settings(state):
         perspectiveZoom, and voxelSize
     """
     view = {}
-    view['position'] = state['navigation']['pose']['position']['voxelCoordinates']
-    view['zoomFactor'] = state['navigation'].get('zoomFactor', None)
-    view['perspectiveOrientation'] = state.get('perspectiveOrientation', None)
-    view['perspectiveZoom'] = state.get('perspectiveZoom', None)
-    view['voxelSize'] = state['navigation']['pose']['position']['voxelSize']
+    view["position"] = state["navigation"]["pose"]["position"]["voxelCoordinates"]
+    view["zoomFactor"] = state["navigation"].get("zoomFactor", None)
+    view["perspectiveOrientation"] = state.get("perspectiveOrientation", None)
+    view["perspectiveZoom"] = state.get("perspectiveZoom", None)
+    view["voxelSize"] = state["navigation"]["pose"]["position"]["voxelSize"]
     return view
 
 
@@ -153,84 +153,88 @@ def get_selected_ids(state, layer=None):
         layer = seg_layers[0]
     else:
         raise ValueError(
-            'Segmentation layer must be specified since the state has more than one')
-    return [int(s) for s in get_layer(state, layer)['segments']]
+            "Segmentation layer must be specified since the state has more than one"
+        )
+    return [int(s) for s in get_layer(state, layer)["segments"]]
 
 
 def _get_type_annotations(state, layer_name, type):
     l = get_layer(state, layer_name)
-    annos = l.get('annotations', [])
-    return [anno for anno in annos if anno['type'] == type]
+    annos = l.get("annotations", [])
+    return [anno for anno in annos if anno["type"] == type]
 
 
 def _get_point_annotations(state, layer_name):
-    return _get_type_annotations(state, layer_name, 'point')
+    return _get_type_annotations(state, layer_name, "point")
 
 
 def _get_sphere_annotations(state, layer_name):
-    return _get_type_annotations(state, layer_name, 'ellipsoid')
+    return _get_type_annotations(state, layer_name, "ellipsoid")
 
 
 def _get_line_annotations(state, layer_name):
-    return _get_type_annotations(state, layer_name, 'line')
+    return _get_type_annotations(state, layer_name, "line")
 
 
 def _get_group_annotations(state, layer_name):
-    return _get_type_annotations(state, layer_name, 'collection')
+    return _get_type_annotations(state, layer_name, "collection")
 
 
 def _extract_point_data(annos):
-    return [[anno.get('point') for anno in annos]]
+    return [[anno.get("point") for anno in annos]]
 
 
 def _extract_sphere_data(annos):
-    pt = [anno.get('center') for anno in annos]
-    rad = [anno.get('radii') for anno in annos]
+    pt = [anno.get("center") for anno in annos]
+    rad = [anno.get("radii") for anno in annos]
     return [pt, rad]
 
 
 def _extract_line_data(annos):
-    ptA = [anno.get('pointA') for anno in annos]
-    ptB = [anno.get('pointB') for anno in annos]
+    ptA = [anno.get("pointA") for anno in annos]
+    ptB = [anno.get("pointB") for anno in annos]
     return [ptA, ptB]
 
 
 def _extract_group_data(annos):
-    pt = [anno.get('source') for anno in annos]
-    anno_id = [anno.get('id') for anno in annos]
+    pt = [anno.get("source") for anno in annos]
+    anno_id = [anno.get("id") for anno in annos]
     return [pt, anno_id]
 
 
 _get_map = {
-    'point': _get_point_annotations,
-    'line': _get_line_annotations,
-    'sphere': _get_sphere_annotations,
-    'group': _get_group_annotations,
+    "point": _get_point_annotations,
+    "line": _get_line_annotations,
+    "sphere": _get_sphere_annotations,
+    "group": _get_group_annotations,
 }
 
 _extraction_map = {
-    'point': _extract_point_data,
-    'line': _extract_line_data,
-    'sphere': _extract_sphere_data,
-    'group': _extract_group_data,
+    "point": _extract_point_data,
+    "line": _extract_line_data,
+    "sphere": _extract_sphere_data,
+    "group": _extract_group_data,
 }
 
 
-def _generic_annotations(state, layer_name, description, linked_segmentations, tags, group, anno_type):
+def _generic_annotations(
+    state, layer_name, description, linked_segmentations, tags, group, anno_type
+):
     annos = _get_map[anno_type](state, layer_name)
     out = _extraction_map[anno_type](annos)
     if description:
-        desc = [anno.get('description', None) for anno in annos]
+        desc = [anno.get("description", None) for anno in annos]
         out.append(desc)
     if linked_segmentations:
-        linked_seg = [[np.uint64(x) for x in anno.get(
-            'segments', [])] for anno in annos]
+        linked_seg = [
+            [np.uint64(x) for x in anno.get("segments", [])] for anno in annos
+        ]
         out.append(linked_seg)
     if tags:
-        tag_list = [anno.get('tagIds', []) for anno in annos]
+        tag_list = [anno.get("tagIds", []) for anno in annos]
         out.append(tag_list)
     if group:
-        group_ids = [anno.get('parentId') for anno in annos]
+        group_ids = [anno.get("parentId") for anno in annos]
         out.append(group_ids)
     if len(out) == 1:
         return out[0]
@@ -238,7 +242,14 @@ def _generic_annotations(state, layer_name, description, linked_segmentations, t
         return out
 
 
-def point_annotations(state, layer_name, description=False, linked_segmentations=False, tags=False, group=False):
+def point_annotations(
+    state,
+    layer_name,
+    description=False,
+    linked_segmentations=False,
+    tags=False,
+    group=False,
+):
     """Get all point annotation points and other info from a layer.
 
     Parameters
@@ -267,11 +278,25 @@ def point_annotations(state, layer_name, description=False, linked_segmentations
     anno_group : list
         List of group ids (as string) or None for annotations. Only returned if group=True
     """
-    return _generic_annotations(state, layer_name, description=description, linked_segmentations=linked_segmentations,
-                                tags=tags, group=group, anno_type='point')
+    return _generic_annotations(
+        state,
+        layer_name,
+        description=description,
+        linked_segmentations=linked_segmentations,
+        tags=tags,
+        group=group,
+        anno_type="point",
+    )
 
 
-def line_annotations(state, layer_name, description=False, linked_segmentations=False, tags=False, group=False):
+def line_annotations(
+    state,
+    layer_name,
+    description=False,
+    linked_segmentations=False,
+    tags=False,
+    group=False,
+):
     """Get all line annotation points and other info from a layer.
 
     Parameters
@@ -302,10 +327,19 @@ def line_annotations(state, layer_name, description=False, linked_segmentations=
     anno_group : list
         List of group ids (as string) or None for annotations. Only returned if group=True
     """
-    return _generic_annotations(state, layer_name, description, linked_segmentations, tags, group, 'line')
+    return _generic_annotations(
+        state, layer_name, description, linked_segmentations, tags, group, "line"
+    )
 
 
-def sphere_annotations(state, layer_name, description=False, linked_segmentations=False, tags=False, group=False):
+def sphere_annotations(
+    state,
+    layer_name,
+    description=False,
+    linked_segmentations=False,
+    tags=False,
+    group=False,
+):
     """Get all sphere annotation points and other info from a layer.
 
     Parameters
@@ -336,10 +370,14 @@ def sphere_annotations(state, layer_name, description=False, linked_segmentation
     anno_group : list
         List of group ids (as string) or None for annotations. Only returned if group=True
     """
-    return _generic_annotations(state, layer_name, description, linked_segmentations, tags, group, 'sphere')
+    return _generic_annotations(
+        state, layer_name, description, linked_segmentations, tags, group, "sphere"
+    )
 
 
-def group_annotations(state, layer_name, description=False, linked_segmentations=False, tags=False):
+def group_annotations(
+    state, layer_name, description=False, linked_segmentations=False, tags=False
+):
     """All group annotations and their associated points
 
     Parameters
@@ -347,7 +385,7 @@ def group_annotations(state, layer_name, description=False, linked_segmentations
     state : dict
         Neuroglancer state as JSON dict
     layer_name : str
-        Annotation layer name    
+        Annotation layer name
     description : bool, optional
         If True, also returns descriptions as well. By default False
     linked_segmentations : bool, optional
@@ -368,8 +406,15 @@ def group_annotations(state, layer_name, description=False, linked_segmentations
     anno_tags : list
         List of N lists of tag ids. Only returned if tags=True.
     """
-    return _generic_annotations(state, layer_name, description=description,
-                                linked_segmentations=linked_segmentations, tags=tags, group=False, anno_type='group')
+    return _generic_annotations(
+        state,
+        layer_name,
+        description=description,
+        linked_segmentations=linked_segmentations,
+        tags=tags,
+        group=False,
+        anno_type="group",
+    )
 
 
 def extract_multicut(state, seg_layer=None):
@@ -402,33 +447,34 @@ def extract_multicut(state, seg_layer=None):
             seg_layer = seg_layers[0]
         else:
             raise ValueError(
-                'State has multiple segmentation layers. Please specify the layer to use.')
-    l = get_layer(state, 'seg')
+                "State has multiple segmentation layers. Please specify the layer to use."
+            )
+    l = get_layer(state, "seg")
     pts = []
     svids = []
     side = []
     root_id = None
 
-    source_data = l['graphOperationMarker'][0]
-    for anno in source_data['annotations']:
-        pts.append(anno['point'])
-        side.append('source')
+    source_data = l["graphOperationMarker"][0]
+    for anno in source_data["annotations"]:
+        pts.append(anno["point"])
+        side.append("source")
         if root_id is None:
-            root_id = int(anno['segments'][1])
-        svid = int(anno['segments'][0])
+            root_id = int(anno["segments"][1])
+        svid = int(anno["segments"][0])
         if svid != root_id:
             svids.append(svid)
         else:
             # This means that no supervoxel was directly selected
             svids.append(np.nan)
 
-    sink_data = l['graphOperationMarker'][1]
-    for anno in sink_data['annotations']:
-        pts.append(anno['point'])
-        side.append('sink')
-        svid = int(anno['segments'][0])
+    sink_data = l["graphOperationMarker"][1]
+    for anno in sink_data["annotations"]:
+        pts.append(anno["point"])
+        side.append("sink")
+        svid = int(anno["segments"][0])
         if root_id is None:
-            root_id = int(anno['segments'][1])
+            root_id = int(anno["segments"][1])
         if svid != root_id:
             svids.append(svid)
         else:
